@@ -1,4 +1,4 @@
-print.ci<-function(x,digits= max(3, getOption("digits") - 3), ...){
+print.ci<-function(x,digits= max(3, getOption("digits")), ...){
 cat("\n")
 cat(x$head,"\n")
 rq<-structure(x$ci,names=x$ends)
